Documentation
¶
Index ¶
- type RevModel
- func (rm *RevModel) GetDamp() float32
- func (rm *RevModel) GetDry() float32
- func (rm *RevModel) GetMode() float32
- func (rm *RevModel) GetRoomSize() float32
- func (rm *RevModel) GetWet() float32
- func (rm *RevModel) GetWidth() float32
- func (rm *RevModel) Mute()
- func (rm *RevModel) ProcessMix(inputL, inputR, outputL, outputR []float32, numSamples, skip int)
- func (rm *RevModel) ProcessReplace(inputL, inputR, outputL, outputR []float32, numSamples, skip int)
- func (rm *RevModel) SetDamp(value float32)
- func (rm *RevModel) SetDry(value float32)
- func (rm *RevModel) SetMode(value float32)
- func (rm *RevModel) SetRoomSize(value float32)
- func (rm *RevModel) SetWet(value float32)
- func (rm *RevModel) SetWidth(value float32)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RevModel ¶
type RevModel struct {
// contains filtered or unexported fields
}
RevModel is a reverb model.
func NewRevModel ¶
func NewRevModel() *RevModel
func (*RevModel) GetRoomSize ¶
func (*RevModel) ProcessMix ¶
ProcessMix processes a block of samples, mixing the result with the contents of outputL and outputR.
func (*RevModel) ProcessReplace ¶
func (rm *RevModel) ProcessReplace(inputL, inputR, outputL, outputR []float32, numSamples, skip int)
ProcessReplace processes a block of samples, replacing the contents of outputL and outputR.
func (*RevModel) SetRoomSize ¶
Click to show internal directories.
Click to hide internal directories.